pub struct StateMiddleware<T>(_);
The middleware for inserting state into a request.

This inserts the inner state value into the request every time the middleware is run, before passing on the request down stream. You can append as many state middlewares as you like, as long as the inner type T does not overlap (otherwise, the last value would win).

This type requires the inner type to be Clone, as it must be cloned on every request. It is recommended to wrap the type in a reference-counting type, like std::sync::Arc, if it is not already in one.

Implementations

Creates an instance of the state middleware with the given value.

Examples
under::http()
    .with(under::middleware::StateMiddleware::new(123u32));